@@ -1,4 +1,4 @@
-#!/usr/bin/python3.11
+#!/usr/bin/python
 
 # Copyright 2003-2023 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
@@ -9,7 +9,7 @@ __author__ = (
     + "modular re-write by: Brian Dolbec (dol-sen)"
 )
 __email__ = "degrenier@easyconnect.fr, " + "brian.dolbec@gmail.com"
-__version__ = "0.6.5"
+__version__ = "0.6.7"
 __productname__ = "eclean"
 __description__ = "A cleaning tool for Gentoo distfiles and binaries."
 
@@ -424,7 +424,7 @@ def parseArgs(options={}):
                 options["unique-use"] = True
             elif o in ("--no-clean-invalid"):
                 options["no-clean-invalid"] = True
-            elif o in ("--skip-vcs"):
+            elif o in ("--skip-vcs") or not options["destructive"]:
                 options["skip-vcs"] = True
             else:
                 return_code = False
@@ -602,11 +602,11 @@ def doAction(action, options, exclude={}, output=None):
             output.einfo("Cleaning " + files_type + "...")
         # do the cleanup, and get size of deleted files
         if options["pretend"]:
-            if options["skip-vcs"]:
+            if options["skip-vcs"] or not options["destructive"]:
                 vcs = {}
             clean_size = cleaner.pretend_clean(clean_me, vcs)
         elif action in ["distfiles"]:
-            if options["skip-vcs"]:
+            if options["skip-vcs"] or not options["destructive"]:
                 vcs = {}
             clean_size = cleaner.clean_dist(clean_me, vcs)
         elif action in ["packages"]:
@@ -623,6 +623,7 @@ def doAction(action, options, exclude={}, output=None):
     elif not options["quiet"]:
         output.einfo("Your " + action + " directory was already clean.")
     if saved and not options["quiet"]:
+        verb = "would be"
         print()
         print(
             pp.emph("   The following ")
